PaymentStatus enum
Payment status tracking for better state management
- Inheritance
- Available extensions
Values
- initializing → const PaymentStatus
- preloadInProgress → const PaymentStatus
- preloadFailed → const PaymentStatus
- webviewLoading → const PaymentStatus
- webviewReady → const PaymentStatus
- paymentInProgress → const PaymentStatus
- paymentCompleted → const PaymentStatus
- paymentFailed → const PaymentStatus
- paymentCancelled → const PaymentStatus
- receiptFetching → const PaymentStatus
- receiptFailed → const PaymentStatus
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isError → bool
-
Available on PaymentStatus, provided by the PaymentStatusExtension extension
no setter - isLoading → bool
-
Available on PaymentStatus, provided by the PaymentStatusExtension extension
no setter - isSuccess → bool
-
Available on PaymentStatus, provided by the PaymentStatusExtension extension
no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - name → String
-
Available on PaymentStatus, provided by the PaymentStatusExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PaymentStatus> - A constant List of the values in this enum, in order of their declaration.