MonerisErrorHandler class
Error Handler for Moneris Payment
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
handleError(
dynamic error, [StackTrace? stackTrace]) → String - Handles different types of errors with appropriate messages
-
logError(
String message, {dynamic error, StackTrace? stackTrace}) → void - Logs errors with consistent formatting
-
logInfo(
String message, {bool enableDebugLogs = false}) → void - Logs informational messages
-
validatePreloadResponse(
Map< String, dynamic> response) → String? - Validates preload response data
-
validateReceiptResponse(
Map< String, dynamic> response) → String? - Validates receipt response data